@@ -1,8 +1,9 @@
 package PMLTQ::Grammar;
-BEGIN {
-  $PMLTQ::Grammar::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Grammar::VERSION = '0.8.3';
 }
-$PMLTQ::Grammar::VERSION = '0.8.2';
+
 # ABSTRACT: Provides L<Parse::RecDescent> grammar for parsing PML-TQ queries
 
 use 5.006;
@@ -25,7 +26,7 @@ PMLTQ::Grammar - Provides L<Parse::RecDescent> grammar for parsing PML-TQ querie
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
