@@ -1,8 +1,9 @@
 package PMLTQ::ParserError;
-BEGIN {
-  $PMLTQ::ParserError::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::ParserError::VERSION = '0.8.3';
 }
-$PMLTQ::ParserError::VERSION = '0.8.2';
+
 # ABSTRACT: Wrapper for parsing error
 
 1; # End of PMLTQ::ParserError
@@ -19,7 +20,7 @@ PMLTQ::ParserError - Wrapper for parsing error
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
