@@ -1,8 +1,9 @@
 package PMLTQ::Relation::ChildnodeIterator;
-BEGIN {
-  $PMLTQ::Relation::ChildnodeIterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::ChildnodeIterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::ChildnodeIterator::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates over child nodes
 
 use 5.006;
@@ -58,7 +59,7 @@ PMLTQ::Relation::ChildnodeIterator - Iterates over child nodes
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
