@@ -1,8 +1,9 @@
 package PMLTQ::Relation::CurrentFilelistIterator;
-BEGIN {
-  $PMLTQ::Relation::CurrentFilelistIterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::CurrentFilelistIterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::CurrentFilelistIterator::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates over files of given file list (calling TredMacro::NextFile())
 
 use 5.006;
@@ -52,7 +53,7 @@ PMLTQ::Relation::CurrentFilelistIterator - Iterates over files of given file lis
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
