@@ -1,8 +1,9 @@
 package PMLTQ::Relation::CurrentTreeIterator;
-BEGIN {
-  $PMLTQ::Relation::CurrentTreeIterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::CurrentTreeIterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::CurrentTreeIterator::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates over nodes of current tree
 
 use 5.006;
@@ -55,7 +56,7 @@ PMLTQ::Relation::CurrentTreeIterator - Iterates over nodes of current tree
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
