@@ -1,8 +1,9 @@
 package PMLTQ::Relation::DescendantIteratorWithBoundedDepth;
-BEGIN {
-  $PMLTQ::Relation::DescendantIteratorWithBoundedDepth::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::DescendantIteratorWithBoundedDepth::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::DescendantIteratorWithBoundedDepth::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates over descendant nodes in given boundaries
 
 use 5.006;
@@ -98,7 +99,7 @@ PMLTQ::Relation::DescendantIteratorWithBoundedDepth - Iterates over descendant n
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
