@@ -1,8 +1,9 @@
 package PMLTQ::Relation::FSFileIterator;
-BEGIN {
-  $PMLTQ::Relation::FSFileIterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::FSFileIterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::FSFileIterator::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates nodes of given fsfile
 
 use 5.006;
@@ -78,7 +79,7 @@ PMLTQ::Relation::FSFileIterator - Iterates nodes of given fsfile
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
