@@ -1,8 +1,9 @@
 package PMLTQ::Relation::Iterator;
-BEGIN {
-  $PMLTQ::Relation::Iterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::Iterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::Iterator::VERSION = '0.8.2';
+
 # ABSTRACT: Base Iterator class
 
 use 5.006;
@@ -49,7 +50,7 @@ PMLTQ::Relation::Iterator - Base Iterator class
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
