@@ -1,8 +1,9 @@
 package PMLTQ::Relation::SiblingIterator;
-BEGIN {
-  $PMLTQ::Relation::SiblingIterator::AUTHORITY = 'cpan:MICHALS';
+our $AUTHORITY = 'cpan:MICHALS';
+{
+  $PMLTQ::Relation::SiblingIterator::VERSION = '0.8.3';
 }
-$PMLTQ::Relation::SiblingIterator::VERSION = '0.8.2';
+
 # ABSTRACT: Iterates over siblings given node
 
 use 5.006;
@@ -61,7 +62,7 @@ PMLTQ::Relation::SiblingIterator - Iterates over siblings given node
 
 =head1 VERSION
 
-version 0.8.2
+version 0.8.3
 
 =head1 AUTHORS
 
